package Passwd::Keyring::Auto::KeyringAPI;
use strict;
use warnings;
1;
